@@ -3,6 +3,7 @@
 import autoBOTLib
 import pandas as pd
 
+
 def run():
     ## Load example data frame
     dataframe = pd.read_csv("../data/insults/train.tsv", sep="\t")
@@ -12,12 +13,16 @@ def run():
     autoBOTLibObj = autoBOTLib.GAlearner(
         train_sequences,
         train_targets,
-        representation_type = "symbolic", ## See the documentation for all possible representation types.
+        representation_type=
+        "symbolic",  ## See the documentation for all possible representation types.
         n_fold_cv=3,
-        memory_storage ="memory",
-        sparsity = 0.1,
-        upsample = False, ## Suitable for imbalanced data - randomized upsampling tends to help.
-        time_constraint=0.2).evolve(strategy = "evolution") ## strategy = "direct-learning" trains a single learner.
+        memory_storage="memory",
+        sparsity=0.1,
+        upsample=
+        False,  ## Suitable for imbalanced data - randomized upsampling tends to help.
+        time_constraint=0.2).evolve(
+            strategy="evolution"
+        )  ## strategy = "direct-learning" trains a single learner.
 
     dataframe2 = pd.read_csv("../data/insults/test.tsv", sep="\t")
     test_sequences = dataframe2['text_a']
@@ -26,7 +31,9 @@ def run():
     print(predictions)
     print(prob_predictions)
 
-    autoBOTLibObj.generate_report(output_folder = "./report/", job_id = "as9y0gb98s")
-    
+    autoBOTLibObj.generate_report(output_folder="./report/",
+                                  job_id="as9y0gb98s")
+
+
 if __name__ == "__main__":
     run()
